@@ -16,7 +16,7 @@ alert(&quot;!&quot;)
 
 snapshots[
     "test_multi_line_code_markdown_with_language 1"
-] = """<pre><code class="javascript">&lt;script&gt;
+] = """<pre><code class="language-javascript">&lt;script&gt;
 alert(&quot;!&quot;)
 &lt;/script&gt;
 </code></pre>"""
